@@ -1,5 +1,5 @@
 --
--- (C) 2013-17 - ntop.org
+-- (C) 2013-18 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -20,7 +20,7 @@ if(host_info["host"] ~= nil) then
    local breakdown = {}
 
    -- Show ARP sent/recv breakdown 
-   stats = interface.getMacInfo(host_info["host"], host_info["vlan"])
+   stats = interface.getMacInfo(host_info["host"])
 
    if stats ~= nil then
       local arp_sent = stats["arp_requests.sent"] + stats["arp_replies.sent"]
@@ -35,6 +35,6 @@ else
    -- Show ARP stats for interface
    stats = interface.getStats()
 
-   print('<tr><td>'..i18n("graphs.arp_requests").."</td><td align='right'>"..formatPackets(stats["arp.requests"]).."</td></tr>")
-   print('<tr><td>'..i18n("graphs.arp_replies").."</td><td align='right'>"..formatPackets(stats["arp.replies"]).."</td></tr>")
+   print('<tr><td>'..i18n("graphs.arp_requests").."</td><td align='right'>"..(stats["arp.requests"]).."</td></tr>")
+   print('<tr><td>'..i18n("graphs.arp_replies").."</td><td align='right'>"..(stats["arp.replies"]).."</td></tr>")
 end
