@@ -2,7 +2,7 @@
 -- (C) 2014-15 - ntop.org
 --
 
-dirs = ntop.getDirs()
+local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "template"
@@ -11,9 +11,11 @@ require "flow_aggregation_utils"
 
 local db_debug = false
 
---- ====================================================================
+local db_utils = {}
 
-function iptonumber(str)
+-- ########################################################
+
+local function iptonumber(str)
    local num = 0
    for elem in str:gmatch("%d+") do
       num = num * 256 + assert(tonumber(elem))
@@ -21,11 +23,12 @@ function iptonumber(str)
    return num
 end
 
+-- ########################################################
 
 function expandIpV4Network(net)
    local address, prefix = splitNetworkPrefix(net)
 
-   if(prefix == nil or prefix > 32 or prefix <= 0) then prefix = 32 end
+   if(prefix == nil or prefix > 32 or prefix < 0) then prefix = 32 end
 
    local num_hosts = 2^(32-prefix)
    local addr = iptonumber(address)
@@ -37,7 +40,9 @@ function expandIpV4Network(net)
    return({ addr, addr+num_hosts-1 })
 end
 
-function flowsTableName(version, force_raw)
+-- ########################################################
+
+local function flowsTableName(version, force_raw)
    if tblname_prefs == nil then
       tblname_prefs = ntop.getPrefs()
    end
@@ -54,9 +59,106 @@ function flowsTableName(version, force_raw)
    return tblname
 end
 
---- ====================================================================
+-- ########################################################
 
-function getInterfaceTopFlows(interface_id, version, host_or_profile, peer, l7proto, l4proto, port, info, begin_epoch, end_epoch, offset, max_num_flows, sort_column, sort_order, aggregated_flows)
+local function allowedNetworksIter(version)
+   if version ~= 4 and version ~= 6 then
+      return function() return nil end
+   end
+
+   local an = ntop.getAllowedNetworks()..","
+   local spl = an:split(",")
+   local pos = 0
+
+   return function()
+      while pos < #spl do
+	 pos = pos + 1
+	 local net = spl[pos]
+	 local v6_net = not isIPv4Network(net)
+
+	 if (v6_net and version == 6) or (not v6_net and version == 4) then
+	    return net
+	 end
+      end
+   end
+end
+
+-- ########################################################
+
+function allowedNetworksRestrictions()
+   for net in allowedNetworksIter(6) do
+      if net:match('[1-9a-fA-F]') then
+	 return true
+      end
+   end
+
+   for net in allowedNetworksIter(4) do
+      local expanded = expandIpV4Network(net)
+      if (expanded[1] > 0 or expanded[2] < 2^32 - 1) then
+	 return true
+      end
+   end
+
+   return false
+end
+
+-- ########################################################
+
+local function allowedNetworksFilter(follow, version, filter_src, filter_dst)
+   local an = ntop.getAllowedNetworks()..","
+   local v4_expanded = {}
+   local expanded_src = {}
+   local expanded_dst = {}
+
+   for net in allowedNetworksIter(version) do
+      -- tprint({net=net, match=net:match('[1-9]'), version=version})
+
+      if version == 6 and net:match('[1-9a-fA-F]') then
+	 -- no results when we've a non-zero ipv6 allowed network
+	 return follow.." AND 1 = 0 "
+      end
+
+      if version == 4 then
+	 local expanded = expandIpV4Network(net)
+	 local filter = {}
+
+	 if filter_src and (expanded[1] > 0 or expanded[2] < 2^32 - 1) then
+	    expanded_src[#expanded_src + 1] = string.format(" (IP_SRC_ADDR >= %d AND IP_SRC_ADDR <= %d) ", expanded[1], expanded[2])
+	 end
+
+	 if filter_dst and (expanded[1] > 0 or expanded[2] < 2^32 - 1) then
+	    expanded_dst[#expanded_dst + 1] = string.format(" (IP_DST_ADDR >= %d AND IP_DST_ADDR <= %d) ", expanded[1], expanded[2])
+	 end
+      end
+   end
+
+   local res = "1 = 1"
+   if version == 4 then
+      -- multiple allowed networks must be evaluated in OR
+      local r = {}
+
+      if table.len(expanded_src) > 0 then
+	 r[#r + 1] = string.format(" (%s) ", table.concat(expanded_src, " OR "))
+      end
+
+      if table.len(expanded_dst) > 0 then
+	 r[#r + 1] = string.format(" (%s) ", table.concat(expanded_dst, " OR "))
+      end
+
+      if table.len(r) > 0 then
+	 res = table.concat(r, " AND ")
+      end
+
+   elseif version == 6 then
+      -- TODO: implement filtering for ipv6 networks
+   end
+
+   return string.format("%s AND (%s)", follow, res)
+end
+
+-- ########################################################
+
+function getInterfaceTopFlows(interface_id, version, host_or_profile, peer, l7proto, l4proto, port, vlan, profile, info, begin_epoch, end_epoch, offset, max_num_flows, sort_column, sort_order, aggregated_flows)
    -- CONVERT(UNCOMPRESS(JSON) USING 'utf8') AS JSON
 
    if(version == 4) then
@@ -73,6 +175,8 @@ function getInterfaceTopFlows(interface_id, version, host_or_profile, peer, l7pr
    if((l7proto ~= "") and (l7proto ~= "-1")) then follow = follow .." AND L7_PROTO="..l7proto end
    if((l4proto ~= "") and (l4proto ~= "-1")) then follow = follow .." AND PROTOCOL="..l4proto end
    if(port ~= "") then follow = follow .." AND (L4_SRC_PORT="..port.." OR L4_DST_PORT="..port..")" end
+   if((vlan ~= nil) and (vlan ~= "")) then follow = follow .." AND VLAN_ID="..vlan end
+   if((profile ~= nil) and (profile ~= "")) then follow = follow .." AND PROFILE='"..profile.."'" end
    if(info ~= "") then follow = follow .." AND (INFO LIKE '%"..info.."%')" end
    follow = follow.." AND (NTOPNG_INSTANCE_NAME='"..ntop.getPrefs()["instance_name"].."'OR NTOPNG_INSTANCE_NAME IS NULL OR NTOPNG_INSTANCE_NAME='')"
    follow = follow.." AND (INTERFACE_ID='"..tonumber(interface_id).."')"
@@ -98,6 +202,8 @@ function getInterfaceTopFlows(interface_id, version, host_or_profile, peer, l7pr
       end
    end
 
+   follow = allowedNetworksFilter(follow, version, true, true)
+
    follow = follow .." order by "..sort_column.." "..sort_order.." limit "..max_num_flows.." OFFSET "..offset
 
    sql = sql .. follow
@@ -115,7 +221,7 @@ function getInterfaceTopFlows(interface_id, version, host_or_profile, peer, l7pr
    end
 end
 
---- ====================================================================
+-- ########################################################
 
 function getFlowInfo(interface_id, version, flow_idx)
    version = tonumber(version)
@@ -126,7 +232,7 @@ function getFlowInfo(interface_id, version, flow_idx)
       sql = "select IP_SRC_ADDR, IP_DST_ADDR"
    end
 
-   follow = " ,L4_SRC_PORT,L4_DST_PORT,VLAN_ID,PROTOCOL,FIRST_SWITCHED,LAST_SWITCHED,PACKETS,IN_BYTES + OUT_BYTES as BYTES,idx,L7_PROTO,INFO,CONVERT(UNCOMPRESS(JSON) USING 'utf8') AS JSON from flowsv"..version
+   follow = " ,L4_SRC_PORT,L4_DST_PORT,VLAN_ID,PROTOCOL,FIRST_SWITCHED,LAST_SWITCHED,PACKETS,IN_BYTES, OUT_BYTES, IN_BYTES + OUT_BYTES as BYTES,idx,L7_PROTO,INFO,CONVERT(UNCOMPRESS(JSON) USING 'utf8') AS JSON from flowsv"..version
    follow = follow.." where idx="..flow_idx
    sql = sql .. follow
 
@@ -143,9 +249,9 @@ function getFlowInfo(interface_id, version, flow_idx)
    end
 end
 
---- ====================================================================
+-- ########################################################
 
-function getNumFlows(interface_id, version, host, protocol, port, l7proto, info, begin_epoch, end_epoch, force_raw_flows)
+function getNumFlows(interface_id, version, host, protocol, port, l7proto, info, vlan, profile, begin_epoch, end_epoch, force_raw_flows, enforce_allowed_networks)
    if(version == nil) then version = 4 end
 
    if(info == "") then info = nil end
@@ -177,6 +283,8 @@ function getNumFlows(interface_id, version, host, protocol, port, l7proto, info,
 
    if((l7proto ~= nil) and (l7proto ~= "")) then sql = sql .." AND L7_PROTO="..l7proto end
    if((protocol ~= nil) and (protocol ~= "")) then sql = sql .." AND PROTOCOL="..protocol end
+   if((vlan ~= nil) and (vlan ~= "")) then sql = sql .." AND VLAN_ID="..vlan end
+   if((profile ~= nil) and (profile ~= "")) then sql = sql .." AND PROFILE='"..profile.."'" end
    if(info ~= nil) then sql = sql .." AND (INFO LIKE '%"..info.."%')" end
 
    if((port ~= nil) and (port ~= "")) then sql = sql .." AND (L4_SRC_PORT="..port.." OR L4_DST_PORT="..port..")" end
@@ -198,6 +306,10 @@ function getNumFlows(interface_id, version, host, protocol, port, l7proto, info,
       end
    end
 
+   if enforce_allowed_networks then
+      sql = allowedNetworksFilter(sql, version, true, true)
+   end
+
    if(db_debug == true) then io.write(sql.."\n") end
 
    res = interface.execSQLQuery(sql)
@@ -212,7 +324,9 @@ function getNumFlows(interface_id, version, host, protocol, port, l7proto, info,
    end
 end
 
-function getOverallTopTalkersSELECT_FROM_WHERE_clause(src_or_dst, v4_or_v6, begin_epoch, end_epoch, ifid, l4proto, port)
+-- ########################################################
+
+function getOverallTopTalkersSELECT_FROM_WHERE_clause(src_or_dst, v4_or_v6, begin_epoch, end_epoch, ifid, l4proto, port, vlan, profile)
    local sql = ""
    local sql_bytes_packets = "PACKETS as packets, "
    local exclude_same_src_dst = false
@@ -251,10 +365,27 @@ function getOverallTopTalkersSELECT_FROM_WHERE_clause(src_or_dst, v4_or_v6, begi
    if((port ~= nil) and (port ~= "")) then
       sql = sql .." AND (L4_SRC_PORT="..port.." OR L4_DST_PORT="..port..")"
    end
+
+   if((vlan ~= nil) and (vlan ~= "")) then
+      sql = sql .." AND VLAN_ID="..vlan
+   end
+
+   if((profile ~= nil) and (profile ~= "")) then
+      sql = sql .." AND PROFILE='"..profile.."'"
+   end
+
+   if src_or_dst     == "IP_DST_ADDR" then
+      sql = allowedNetworksFilter(sql, v4_or_v6, false, true)
+   elseif src_or_dst == "IP_SRC_ADDR" then
+      sql = allowedNetworksFilter(sql, v4_or_v6, true, false)
+   end
+
    return sql..'\n'
 end
 
-function getOverallTopTalkers(interface_id, l4proto, port, info, begin_epoch, end_epoch, sort_column, sort_order, offset, limit)
+-- ########################################################
+
+function getOverallTopTalkers(interface_id, l4proto, port, vlan, profile, info, begin_epoch, end_epoch, sort_column, sort_order, offset, limit)
    -- retrieves top talkers in the given time range
 
    if(info == "") then info = nil end
@@ -269,13 +400,13 @@ function getOverallTopTalkers(interface_id, l4proto, port, info, begin_epoch, en
    sql = sql.." FROM "
 
    sql = sql.."("
-   sql = sql..getOverallTopTalkersSELECT_FROM_WHERE_clause('IP_SRC_ADDR', 4, begin_epoch, end_epoch, interface_id, l4proto, port)
+   sql = sql..getOverallTopTalkersSELECT_FROM_WHERE_clause('IP_SRC_ADDR', 4, begin_epoch, end_epoch, interface_id, l4proto, port, vlan, profile)
    sql = sql.." UNION ALL "
-   sql = sql..getOverallTopTalkersSELECT_FROM_WHERE_clause('IP_DST_ADDR', 4, begin_epoch, end_epoch, interface_id, l4proto, port)
+   sql = sql..getOverallTopTalkersSELECT_FROM_WHERE_clause('IP_DST_ADDR', 4, begin_epoch, end_epoch, interface_id, l4proto, port, vlan, profile)
    sql = sql.." UNION ALL "
-   sql = sql..getOverallTopTalkersSELECT_FROM_WHERE_clause('IP_SRC_ADDR', 6, begin_epoch, end_epoch, interface_id, l4proto, port)
+   sql = sql..getOverallTopTalkersSELECT_FROM_WHERE_clause('IP_SRC_ADDR', 6, begin_epoch, end_epoch, interface_id, l4proto, port, vlan, profile)
    sql = sql.." UNION ALL "
-   sql = sql..getOverallTopTalkersSELECT_FROM_WHERE_clause('IP_DST_ADDR', 6, begin_epoch, end_epoch, interface_id, l4proto, port)
+   sql = sql..getOverallTopTalkersSELECT_FROM_WHERE_clause('IP_DST_ADDR', 6, begin_epoch, end_epoch, interface_id, l4proto, port, vlan, profile)
    sql = sql..") talkers"
    sql = sql.." group by addr "
 
@@ -317,8 +448,9 @@ function getOverallTopTalkers(interface_id, l4proto, port, info, begin_epoch, en
    end
 end
 
+-- ########################################################
 
-function getHostTopTalkers(interface_id, host, l7_proto_id, l4_proto_id, port, info, begin_epoch, end_epoch, sort_column, sort_order, offset, limit)
+function getHostTopTalkers(interface_id, host, l7_proto_id, l4_proto_id, port, vlan, profile, info, begin_epoch, end_epoch, sort_column, sort_order, offset, limit)
    -- obtains host top talkers, possibly restricting the range only to l7_proto_id
    if host == nil or host == "" then return {} end
 
@@ -355,6 +487,14 @@ function getHostTopTalkers(interface_id, host, l7_proto_id, l4_proto_id, port, i
    if((port ~= nil) and (port ~= "")) then
       sql = sql .." AND (L4_SRC_PORT="..port.." OR L4_DST_PORT="..port..")"
    end
+
+   if((vlan ~= nil) and (vlan ~= "")) then
+      sql = sql .." AND VLAN_ID="..vlan
+   end
+
+   if((profile ~= nil) and (profile ~= "")) then
+      sql = sql .." AND PROFILE='"..profile.."'"
+   end
    if(info ~= nil) then
       sql = sql .." AND (INFO LIKE '%"..info.."%')"
    end
@@ -368,6 +508,8 @@ function getHostTopTalkers(interface_id, host, l7_proto_id, l4_proto_id, port, i
       sql = sql .." AND (IP_SRC_ADDR='"..host.."' OR IP_DST_ADDR='"..host.."')"
    end
 
+   sql = allowedNetworksFilter(sql, version, true, true)
+
    sql = sql..") peers"
 
    -- we don't care about the order so we group by least and greatest
@@ -414,7 +556,9 @@ function getHostTopTalkers(interface_id, host, l7_proto_id, l4_proto_id, port, i
    end
 end
 
-function getAppTopTalkersSELECT_FROM_WHERE_clause(src_or_dst, v4_or_v6, begin_epoch, end_epoch, ifid, l7_proto_id, l4_proto_id, port)
+-- ########################################################
+
+function getAppTopTalkersSELECT_FROM_WHERE_clause(src_or_dst, v4_or_v6, begin_epoch, end_epoch, ifid, l7_proto_id, l4_proto_id, port, vlan, profile)
    local sql = ""
    local sql_bytes_packets = "PACKETS as packets, "
    local exclude_same_src_dst = false
@@ -456,10 +600,26 @@ function getAppTopTalkersSELECT_FROM_WHERE_clause(src_or_dst, v4_or_v6, begin_ep
       sql = sql .." AND (L4_SRC_PORT="..port.." OR L4_DST_PORT="..port..")"
    end
 
+   if((vlan ~= nil) and (vlan ~= "")) then
+      sql = sql .." AND VLAN_ID="..vlan
+   end
+
+   if((profile ~= nil) and (profile ~= "")) then
+      sql = sql .." AND PROFILE='"..profile.."'"
+   end
+
+   if src_or_dst     == "IP_DST_ADDR" then
+      sql = allowedNetworksFilter(sql, v4_or_v6, false, true)
+   elseif src_or_dst == "IP_SRC_ADDR" then
+      sql = allowedNetworksFilter(sql, v4_or_v6, true, false)
+   end
+
    return sql..'\n'
 end
 
-function getAppTopTalkers(interface_id, l7_proto_id, l4_proto_id, port, info, begin_epoch, end_epoch, sort_column, sort_order, offset, limit)
+-- ########################################################
+
+function getAppTopTalkers(interface_id, l7_proto_id, l4_proto_id, port, vlan, profile, info, begin_epoch, end_epoch, sort_column, sort_order, offset, limit)
    -- retrieves top talkers in the given time range
    if(info == "") then info = nil end
 
@@ -473,13 +633,13 @@ function getAppTopTalkers(interface_id, l7_proto_id, l4_proto_id, port, info, be
    sql = sql.." FROM "
 
    sql = sql.."("
-   sql = sql..getAppTopTalkersSELECT_FROM_WHERE_clause('IP_SRC_ADDR', 4, begin_epoch, end_epoch, interface_id, l7_proto_id, l4_proto_id, port)
+   sql = sql..getAppTopTalkersSELECT_FROM_WHERE_clause('IP_SRC_ADDR', 4, begin_epoch, end_epoch, interface_id, l7_proto_id, l4_proto_id, port, vlan, profile)
    sql = sql.." UNION ALL "
-   sql = sql..getAppTopTalkersSELECT_FROM_WHERE_clause('IP_DST_ADDR', 4, begin_epoch, end_epoch, interface_id, l7_proto_id, l4_proto_id, port)
+   sql = sql..getAppTopTalkersSELECT_FROM_WHERE_clause('IP_DST_ADDR', 4, begin_epoch, end_epoch, interface_id, l7_proto_id, l4_proto_id, port, vlan, profile)
    sql = sql.." UNION ALL "
-   sql = sql..getAppTopTalkersSELECT_FROM_WHERE_clause('IP_SRC_ADDR', 6, begin_epoch, end_epoch, interface_id, l7_proto_id, l4_proto_id, port)
+   sql = sql..getAppTopTalkersSELECT_FROM_WHERE_clause('IP_SRC_ADDR', 6, begin_epoch, end_epoch, interface_id, l7_proto_id, l4_proto_id, port, vlan, profile)
    sql = sql.." UNION ALL "
-   sql = sql..getAppTopTalkersSELECT_FROM_WHERE_clause('IP_DST_ADDR', 6, begin_epoch, end_epoch, interface_id, l7_proto_id, l4_proto_id, port)
+   sql = sql..getAppTopTalkersSELECT_FROM_WHERE_clause('IP_DST_ADDR', 6, begin_epoch, end_epoch, interface_id, l7_proto_id, l4_proto_id, port, vlan, profile)
    sql = sql..") talkers"
    sql = sql.." group by addr "
 
@@ -521,10 +681,13 @@ function getAppTopTalkers(interface_id, l7_proto_id, l4_proto_id, port, info, be
    end
 end
 
-function getTopApplications(interface_id, peer1, peer2, l7_proto_id, l4_proto_id, port, info, begin_epoch, end_epoch, sort_column, sort_order, offset, limit)
+-- ########################################################
+
+function getTopApplications(interface_id, peer1, peer2, l7_proto_id, l4_proto_id, port, vlan, profile, info, begin_epoch, end_epoch, sort_column, sort_order, offset, limit)
+   -- tprint({n="getTopApplications", peer1=peer1, peer2=peer2})
    -- if both peers are nil, top applications are overall in the time range
-   -- if peer1 is nil nad peer2 is not nil, then top apps are for peer1
-   -- if peer2 is nil nad peer1 is not nil, then top apps are for peer2
+   -- if peer1 is nil and peer2 is not nil, then top apps are for peer1
+   -- if peer2 is nil and peer1 is not nil, then top apps are for peer2
    -- if both peer2 and peer2 are not nil, then top apps are computed between peer1 and peer2
    -- sort_column and sort_order are used to sort the results
    -- offset and limit are used to paginate the results
@@ -542,11 +705,18 @@ function getTopApplications(interface_id, peer1, peer2, l7_proto_id, l4_proto_id
    sql = sql.." AND (NTOPNG_INSTANCE_NAME='"..ntop.getPrefs()["instance_name"].."'OR NTOPNG_INSTANCE_NAME IS NULL OR NTOPNG_INSTANCE_NAME='')"
    sql = sql.." AND (INTERFACE_ID='"..tonumber(interface_id).."')"
 
-
    if((port ~= nil) and (port ~= "")) then
       sql = sql .." AND (L4_SRC_PORT="..port.." OR L4_DST_PORT="..port..")"
    end
 
+   if((vlan ~= nil) and (vlan ~= "")) then
+      sql = sql .." AND VLAN_ID="..vlan
+   end
+
+   if((profile ~= nil) and (profile ~= "")) then
+      sql = sql .." AND PROFILE='"..profile.."'"
+   end
+
    if l7_proto_id and l7_proto_id ~="" then sql = sql.." AND L7_PROTO = "..tonumber(l7_proto_id) end
    if l4_proto_id and l4_proto_id ~="" then sql = sql.." AND PROTOCOL = "..tonumber(l4_proto_id) end
    if(info ~= nil) then sql = sql .." AND (INFO LIKE '%"..info.."%')" end
@@ -566,7 +736,6 @@ function getTopApplications(interface_id, peer1, peer2, l7_proto_id, l4_proto_id
       end
    end
 
-
    sql = sql.." group by L7_PROTO "
 
    -- ORDER
@@ -605,64 +774,26 @@ function getTopApplications(interface_id, peer1, peer2, l7_proto_id, l4_proto_id
    end
 end
 
-function checkOpenFiles()
-   local prefs = ntop.getPrefs()
-
-   local interfaces = interface.getIfNames()
-   local num_interfaces = 0
-   for _, i in pairs(interfaces) do num_interfaces = num_interfaces + 1 end
-
-   local alert_severity = alertSeverity("warning")
-   local alert_type = alertType("open_files_limit_too_small")
-   local alert_id = "open_files_limit_too_small"
-   local alert_msg = i18n("alert_messages.open_files_limit_too_small")
-
-   local open_files_too_small = false
-
-   if prefs.are_alerts_enabled == true and prefs.is_dump_flows_to_mysql_enabled == true and
-   ntop.getPref("ntopng.prefs.mysql_check_open_files_limit") == "1" then
-
-      local num_tables = 4 -- flowsv4, flowsv6, aggrflowsv4 and aggrflowsv6
-      local num_partitions = 8 -- keep this in sync with mysql create table statements in MySQLDB.cpp
-      local data_and_indices = 2 -- MYD for data and MYI for indices (valid only for MyISAM)
-      local num_connections_per_interface = 2 -- one in MySQLDB::queryLoop and the other is mysql class member
-
-      -- https://dev.mysql.com/doc/refman/5.7/en/table-cache.html explains how mysql open files
-      -- i.e., "To minimize the problem with multiple client sessions having different states
-      -- on the same table, the table is opened independently by each concurrent session."
-      --
-      -- The worst case of maximum open files can occur, for example, during daily cleanup operations
-      -- when all the partitions in all the tables are opened to clear old flows
-      local worst_case_max_num_open_files = num_tables * num_interfaces * num_partitions * data_and_indices * num_connections_per_interface
-
-      local query = interface.execSQLQuery("show global variables like 'open_files_limit'")
-      local open_files_limit
-      if query == nil or query[1] == nil or query[1]["Value"] == nil then
-	 return
-      end
-      open_files_limit = tonumber(query[1]["Value"])
-
-
-      -- raise an alert if the worst case number is >= the 80% of open_files_limit
-      if worst_case_max_num_open_files >= open_files_limit * .8 then
-	 open_files_too_small = true
-      end
+-- ########################################################
 
+function db_utils.harverstExpiredMySQLFlows(ifname, mysql_retention, verbose)
+   local dbtables = {"flowsv4", "flowsv6"}
+   if useAggregatedFlows() then
+      dbtables[#dbtables+1] = "aggrflowsv4"
+      dbtables[#dbtables+1] = "aggrflowsv6"
    end
 
-   ::set_alert_status::
-   for ifid, ifname in pairs(interfaces) do
-      interface.select(ifname)
-      local alert_cache = interface.getCachedNumAlerts()
-      local engaged_alerts = alert_cache["num_alerts_engaged"]
+   if tonumber(ifname) == nil then
+      ifname = getInterfaceId(ifname)
+   end
 
-      if open_files_too_small == true then
-	 interface.engageInterfaceAlert(alertEngine("startup"), alert_id, alert_type, alert_severity, alert_msg)
-	 engaged_alerts = engaged_alerts + 1
-      else
-	 if engaged_alerts > 0 then
-	    interface.releaseInterfaceAlert(alertEngine("startup"), alert_id, alert_type, alert_severity, alert_msg)
-	 end
-      end
+   for _, tb in pairs(dbtables) do
+      local sql = "DELETE FROM "..tb.." where FIRST_SWITCHED < "..mysql_retention
+      sql = sql.." AND (INTERFACE_ID = "..ifname..")"
+      sql = sql.." AND (NTOPNG_INSTANCE_NAME='"..ntop.getPrefs()["instance_name"].."' OR NTOPNG_INSTANCE_NAME IS NULL OR NTOPNG_INSTANCE_NAME='')"
+      interface.execSQLQuery(sql)
+      if(verbose) then io.write(sql.."\n") end
    end
 end
+
+return db_utils
