@@ -1,10 +1,12 @@
+--
+-- (C) 2014-18 - ntop.org
+--
+
 require "lua_utils"
 require "flow_aggregation_utils"
 
 local json = require ("dkjson")
 
-local pcap_status_url = ntop.getHttpPrefix().."/lua/get_nbox_data.lua?nbox_action=status"
-local pcap_request_url = ntop.getHttpPrefix().."/lua/get_nbox_data.lua?nbox_action=schedule"
 local favourites_url = ntop.getHttpPrefix().."/lua/get_historical_favourites.lua"
 local flows_download_url = ntop.getHttpPrefix().."/lua/get_db_flows.lua"
 
@@ -57,7 +59,7 @@ function getParams(url) {
 }
 
 /* adds a CSS style to replace the / in the breadcrumb */
-var style = $('<style>#search-criteria:before {content:"]] print(i18n("db_explorer.observation_period")) print[[:";}</style>');
+var style = $("<style>#search-criteria:before {content:\"]] print(i18n("db_explorer.observation_period")) print[[:\";}</style>");
 $('html > head').append(style);
 function addObservationPeriodToBreadCrumb(params_url, breadcrumb_id){
   var params = getParams(params_url);
@@ -91,11 +93,15 @@ function buildRequestData(source_div_id){
   var l7_proto_id = $('#' + source_div_id).attr("l7_proto_id");
   var l4_proto_id = $('#' + source_div_id).attr("l4_proto_id");
   var port = $('#' + source_div_id).attr("port");
+  var vlan = $('#' + source_div_id).attr("vlan");
+  var profile = $('#' + source_div_id).attr("profile");
   var res = {epoch_begin: epoch_begin, epoch_end: epoch_end};
   if (typeof ifId != 'undefined') res.ifid = ifId;
   if (typeof host != 'undefined') res.peer1 = host;
   if (typeof peer != 'undefined') res.peer2 = peer;
   if (typeof port != 'undefined') res.port = port;
+  if (typeof vlan != 'undefined') res.vlan = vlan;
+  if (typeof profile != 'undefined') res.profile = profile;
   if (typeof l7_proto_id != 'undefined'){
     res.l7_proto_id = l7_proto_id;
     res.l7proto = l7_proto_id;
@@ -143,7 +149,6 @@ if zoom_vals ~= nil then
 end
 print[[
 };
-console.log(zoom_vals);
 
 function populateHistoricalDbExplorerLink(the_td, host, l7_proto) {
   var url_params = getParams(window.location.href);
@@ -164,7 +169,7 @@ function populateHistoricalDbExplorerLink(the_td, host, l7_proto) {
   if(url_params["zoom"]) { /* This is a chart url */
     var zoom = url_params["zoom"];
     var epoch = url_params["epoch"];
-    if(epoch === undefined) {
+    if(!epoch) {
       url_params["epoch_end"] = Math.round(new Date() / 1000); /* now */
       url_params["epoch_begin"] = url_params["epoch_end"] - zoom_vals[zoom];
     } else {
@@ -324,20 +329,10 @@ function historicalDownloadButtonsBar(button_id, pcap_request_data_container_div
              print [[<a class="btn btn-default btn-sm" href="#" role="button" id="download_flows_v6_]] print(button_id) print[[" style="]] print(style_ipv6) print[[">]] print(i18n("ipv6")) print[[</a>]]
 	end
 
-	print [[</div>]]
-	  if interface.isPacketInterface()
-	    and ntop.getCache("ntopng.prefs.nbox_integration") == "1"
-	    and haveAdminPrivileges() then
-       print[[ <div class='col-md-2'><div style='margin-bottom:0.4em;'>
-	       ]] print(i18n("db_explorer.extract_pcap")) print[[: <a class="btn btn-default btn-sm]]
-	       print[[" href="#" role="button" id="extract_pcap_]] print(button_id)
-	       print[["><i class="fa fa-download fa-lg"></i></a></div>
-	       <span id="pcap_download_msg_]] print(button_id) print[[">]]
-	       print[[</span>
-	       </div>]]
-	  end
-
-	  print[[<div class='col-md-]] print(displacement) print[['>
+	print [[
+        <p class="text-muted">]] print(i18n("db_explorer.download_flows_limit")) print[[</p>
+	</div>
+	<div class='col-md-]] print(displacement) print[['>
        </div>
      </div>
 
@@ -377,35 +372,6 @@ print[[
   }
 ]]
 
-if ntop.getCache("ntopng.prefs.nbox_integration") == "1" and haveAdminPrivileges() then
-print[[
-   $('#extract_pcap_]] print(button_id) print[[').click(function (event)
-  {
-    event.preventDefault();
-    var perror = function(msg){
-      alert("Request failed: " + msg);
-      $('#pcap_download_msg_]] print(button_id) print[[').show().fadeOut(4000).html("<small>]] print(i18n("db_explorer.request_failed")) print[[.</small>");
-    };
-
-    $.ajax({type: 'GET', url: "]] print(pcap_request_url) print [[",
-    data: buildRequestData(']] print(pcap_request_data_container_div_id) print[['),
-      success: function(data) {
-	data = jQuery.parseJSON(data);
-	if (data["result"] === "KO"){
-	  perror(data["description"]);
-	} else if (data["result"] == "OK"){
-	  $('#pcap_download_msg_]] print(button_id) print[[').show().fadeOut(4000).html('<small>]] print(i18n("db_explorer.ok_request_sent")) print[[.</small>');
-	} else { alert('Unknown response.'); }
-      },
-      error: function() {
-	perror('An HTTP error occurred.');
-      }
-    });
-  });
-]]
-  end
-
-
 print[[
  </script>
   <br>
@@ -423,8 +389,9 @@ function printFlowsCountColumn()
    return col
 end
 
-function historicalTopTalkersTable(ifid, epoch_begin, epoch_end, host, l7proto, l4proto, port)
+function historicalTopTalkersTable(ifid, epoch_begin, epoch_end, host, l7proto, l4proto, port, vlan, profile)
    local breadcrumb_root = "interface"
+   local container_params = ' epoch_begin="" epoch_end="" host="" peer="" l7_proto_id="" l7_proto="" l4_proto_id="" l4_proto="" '
    local host_talkers_url_params = ""
    local interface_talkers_url_params = ""
    local isv6 = isIPv6Address(host)
@@ -435,7 +402,6 @@ function historicalTopTalkersTable(ifid, epoch_begin, epoch_end, host, l7proto,
    if l7proto ~= "" and l7proto ~= nil and not string.starts(tostring(l7proto), 'all') then
       if not isnumber(l7proto) then
 	 local id
-	 l7proto = string.gsub(l7proto, "%.rrd", "")
 	 id = interface.getnDPIProtoId(l7proto)
 	 if id ~= -1 then
 	    l7proto = id
@@ -456,6 +422,18 @@ function historicalTopTalkersTable(ifid, epoch_begin, epoch_end, host, l7proto,
       interface_talkers_url_params = interface_talkers_url_params.."&port="..tonumber(port)
    end
 
+   if vlan ~= "" and vlan ~= nil and tonumber(vlan) ~= nil then
+      interface_talkers_url_params = interface_talkers_url_params.."&vlan="..tostring(vlan)
+      container_params = container_params..' vlan="'..(tostring(vlan) or '')..'"'
+   else
+      container_params = container_params..' vlan=0 '
+   end
+
+   if profile ~= "" and profile ~= nil then
+      interface_talkers_url_params = interface_talkers_url_params.."&profile="..profile
+      container_params = container_params..' profile="'..(profile or '')..'"'
+   end
+
    if host and host ~= "" then
       host_talkers_url_params = interface_talkers_url_params.."&peer1="..host
       breadcrumb_root = "host"
@@ -474,7 +452,7 @@ function historicalTopTalkersTable(ifid, epoch_begin, epoch_end, host, l7proto,
 
 
 <!-- attach some status information to the historical container -->
-<div id="historical-container" epoch_begin="" epoch_end="" host="" peer="" l7_proto_id="" l7_proto="" l4_proto_id="" l4_proto="">
+<div id="historical-container" ]] print(container_params) print[[>
 
 
   <div class="row">
@@ -500,7 +478,17 @@ function historicalTopTalkersTable(ifid, epoch_begin, epoch_end, host, l7proto,
   <div id="flows-per-pair-container"> </div>
 </div>
 
-]] historicalDownloadButtonsBar("pcap-button-top-talkers", "historical-container", not(isv6), isv6) print [[
+]] historicalDownloadButtonsBar("pcap-button-top-talkers", "historical-container", not(isv6), isv6)
+
+if allowedNetworksRestrictions() then
+   print("<b>"..i18n("notes").."</b>")
+   print("<li>"..i18n("note_flow_search_allowed_networks",{nets=ntop.getAllowedNetworks()}).."</li>")
+   print("<li>"..i18n("note_flow_search_allowed_networks_ipv6").."</li>")
+   print("<li>"..i18n("note_flow_search_allowed_networks_talkers").."</li>")
+end
+
+print [[
+
 
 <script type="text/javascript">
 ]] commonJsUtils() print[[
@@ -810,7 +798,7 @@ var populateFlowsPerHostsPairTable = function(peer1, peer2, l7_proto_id, num_flo
 	title: "",]]
 	print("url: '"..ntop.getHttpPrefix().."/lua/get_db_flows.lua?ifid="..tostring(ifId)..interface_talkers_url_params.."&peer1=' + peer1 + '&peer2=' + peer2 + '&l7_proto_id=' + l7_proto_id")
 
-	if useAggregatedFlows() == false then
+	if not useAggregatedFlows() and not allowedNetworksRestrictions() then
 	   -- speed up by passing the number of flows that is already calculated when browsing raw flows
 	   print("+ '&limit=' + num_flows")
 	end
@@ -890,12 +878,27 @@ end
 ]]
 end
 
-function historicalTopApplicationsTable(ifid, epoch_begin, epoch_end, host)
+function historicalTopApplicationsTable(ifid, epoch_begin, epoch_end, host, vlan, profile)
    local breadcrumb_root = "interface"
+   local container_params = ' epoch_begin="" epoch_end="" host="" peer="" l7_proto_id="" l7_proto="" l4_proto_id="" l4_proto="" '
    local top_apps_url_params=""
    local isv6 = isIPv6Address(host)
+
    top_apps_url_params = top_apps_url_params.."&epoch_begin="..epoch_begin
    top_apps_url_params = top_apps_url_params.."&epoch_end="..epoch_end
+   
+   if vlan ~= "" and vlan ~= nil and tonumber(vlan) ~= nil then
+      top_apps_url_params = top_apps_url_params.."&vlan="..tostring(vlan)
+      container_params = container_params..' vlan="'..(tostring(vlan) or '')..'"'
+   else
+      container_params = container_params..' vlan=0 '
+   end
+
+   if profile ~= "" and profile ~= nil then
+      top_apps_url_params = top_apps_url_params.."&profile="..profile
+      container_params = container_params..' profile="'..(profile or '')..'"'
+   end
+
    if host and host ~= "" then
       breadcrumb_root="host"
    end
@@ -908,8 +911,7 @@ function historicalTopApplicationsTable(ifid, epoch_begin, epoch_end, host)
 <ol class="breadcrumb" id="bc-apps" style="margin-bottom: 5px;"]] print('root="'..breadcrumb_root..'"') print [[>
 </ol>
 
-<div id="historical-apps-container" epoch_begin="" epoch_end="" host="" peer="" l7_proto_id="" l7_proto="" l4_proto_id="" l4_proto="">
-
+<div id="historical-apps-container" ]] print(container_params) print[[>
 
   <div class="row">
     <div class="form-group">
@@ -936,7 +938,16 @@ function historicalTopApplicationsTable(ifid, epoch_begin, epoch_end, host)
   <div id="flows-per-pair-by-app-container"> </div>
 </div>
 
-]] historicalDownloadButtonsBar("pcap-button-top-protocols", "historical-apps-container", not(isv6), isv) print [[
+]] historicalDownloadButtonsBar("pcap-button-top-protocols", "historical-apps-container", not(isv6), isv6)
+
+if allowedNetworksRestrictions() then
+   print("<b>"..i18n("notes").."</b>")
+   print("<li>"..i18n("note_flow_search_allowed_networks",{nets=ntop.getAllowedNetworks()}).."</li>")
+   print("<li>"..i18n("note_flow_search_allowed_networks_ipv6").."</li>")
+   print("<li>"..i18n("note_flow_search_allowed_networks_applications").."</li>")
+end
+
+print [[
 
 <script type="text/javascript">
 var totalRows = -1;
@@ -1245,7 +1256,7 @@ var populateFlowsPerHostPairByApplicationTable = function(peer1, peer2, l7_proto
 	title: "",]]
 	print("url: '"..ntop.getHttpPrefix().."/lua/get_db_flows.lua?ifid="..tostring(ifId)..top_apps_url_params.."&peer1=' + peer1 + '&peer2=' + peer2 + '&l7_proto_id=' + l7_proto_id")
 	
-	if useAggregatedFlows() == false then
+	if not useAggregatedFlows() and not allowedNetworksRestrictions() then
 	   -- speed up by passing the number of flows that is already calculated when browsing raw flows
 	   print("+ '&limit=' + num_flows")
 	end
@@ -1407,113 +1418,9 @@ $('a[href="#historical-top-apps"]').on('shown.bs.tab', function (e) {
 ]]
 end
 
-
-function historicalPcapsTable()
-print[[
-<div id="table-pcaps"></div>
-<script>
-
-function jump_to_nbox_activity_scheduler(){
-  var url = document.URL;
-  res = url.split("http://");
-  if(res[0]=="") url=res[1]; else url=res[0];
-  res = url.split("https://");
-  if(res[0]=="") url=res[1]; else url=res[0];
-  res = url.split("/");
-  url = res[0];
-  res = url.split(":");
-  url = res[0];
-  window.open("https://"+url+"/ntop-bin/config_scheduler.cgi", "_blank");
-}
-
-function download_pcap_from_nbox(task_id){
-  var url = document.URL;
-  res = url.split("http://");
-  if(res[0]=="") url=res[1]; else url=res[0];
-  res = url.split("https://");
-  if(res[0]=="") url=res[1]; else url=res[0];
-  res = url.split("/");
-  url = res[0];
-  res = url.split(":");
-  url = res[0];
-  window.open("https://"+url+"/ntop-bin/run.cgi?script=n2disk_filemanager.cgi&opt=download_pcap&dir=/storage/n2disk/&pcap_name=/storage/n2disk/"+task_id+".pcap", "_blank");
-}
-
-var populatePcapsTable = function(){
-  $("#table-pcaps").datatable({
-    title: "]] print(i18n("db_explorer.pcaps")) print[[",
-    url: "]] print (ntop.getHttpPrefix()) print [[/lua/get_nbox_data.lua?nbox_action=status" ,
-    title: "]] print(i18n("db_explorer.pcap_requests_and_status")) print[[",
-]]
-
--- Set the preference table
-preference = tablePreferences("rows_number","5")
-if (preference ~= "") then print ('perPage: '..preference.. ",\n") end
-
--- Automatic default sorted. NB: the column must exist.
-print ('sort: [ ["' .. getDefaultTableSort("pcaps") ..'","' .. getDefaultTableSortOrder("pcaps").. '"] ],')
-
-print [[
-	       showPagination: true,
-		columns: [
-			 {
-			     title: "]] print(i18n("db_explorer.task_id")) print[[",
-				 field: "column_task_id",
-				 sortable: true,
-			     css: {
-				textAlign: 'left'
-			     }
-				 },
-			     {
-			     title: "]] print(i18n("db_explorer.filter_bpf")) print[[",
-				 field: "column_bpf",
-				 sortable: true,
-			     css: {
-				textAlign: 'left'
-			     }
-				 },
-			     {
-			     title: "]] print(i18n("status")) print[[",
-				 field: "column_status",
-				 sortable: true,
-			     css: {
-				textAlign: 'center'
-			     }
-
-				 },
-			     {
-			     title: "]] print(i18n("actions")) print[[",
-				 field: "column_actions",
-				 sortable: true,
-			     css: {
-				textAlign: 'center'
-			     }
-				 }
-			     ]
-	       });
-
-};
-
-$('a[href="#historical-pcaps"]').on('shown.bs.tab', function (e) {
-  if ($('a[href="#historical-pcaps"]').attr("loaded") == 1){
-    enableAllDropdownsAndTabs();
-    // do nothing if the tabs have already been computed and populated
-    return;
-  }
-
-  var target = $(e.target).attr("href"); // activated tab
-  populatePcapsTable();
-  // Finally set a loaded flag for the current tab
-  $('a[href="#historical-pcaps"]').attr("loaded", 1);
-});
-
-</script>
-]]
-end
-
 -- ##########################################
 
-function historicalFlowsTab(ifId, host, epoch_begin, epoch_end, l7proto, l4proto, port, info)
+function historicalFlowsTab(ifId, host, epoch_begin, epoch_end, l7proto, l4proto, port, info, vlan, profile)
    -- prepare some attributes that will be attached to divs
    local div_data = ""
 
@@ -1535,7 +1442,6 @@ function historicalFlowsTab(ifId, host, epoch_begin, epoch_end, l7proto, l4proto
    end
    if l7proto ~= "" and l7proto ~= nil and not string.starts(tostring(l7proto), 'all') then
       if not isnumber(l7proto) then
-	 l7proto = string.gsub(l7proto, "%.rrd", "")
 	 local id = interface.getnDPIProtoId(l7proto)
 	 if id ~= -1 then
 	    l7proto = id
@@ -1554,6 +1460,14 @@ function historicalFlowsTab(ifId, host, epoch_begin, epoch_end, l7proto, l4proto
       _GET["port"] = port
       div_data = div_data..' port="'..port..'" '
    end
+   if vlan ~= "" and vlan ~= nil then
+      _GET["vlan"] = vlan
+      div_data = div_data..' vlan="'..vlan..'" '
+   end
+   if profile ~= "" and profile ~= nil then
+      _GET["profile"] = profile
+      div_data = div_data..' profile="'..profile..'" '
+   end
 
    print[[
 
@@ -1587,7 +1501,7 @@ print [[
            <tr>
              <th>&nbsp;</th>]]
 
-if useAggregatedFlows() == false then -- pointless to show counters for aggregations to the user
+if not useAggregatedFlows() then -- pointless to show counters for aggregations to the user
    print[[<th>]] print(i18n("db_explorer.total_flows"))print[[</th>]]
 end
 
@@ -1596,6 +1510,9 @@ print[[<th>]] print(i18n("db_explorer.traffic_volume")) print[[</th>
            </tr>
         </table>
       </div>
+]]
+
+print[[
     </div>
 ]]
 
@@ -1618,10 +1535,20 @@ print[[<th>]] print(i18n("db_explorer.traffic_volume")) print[[</th>
     </div>
 ]]
 
+if allowedNetworksRestrictions() then
+   print("<b>"..i18n("notes").."</b>")
+   print("<li>"..i18n("note_flow_search_allowed_networks",{nets=ntop.getAllowedNetworks()}).."</li>")
+   print("<li>"..i18n("note_flow_search_allowed_networks_ipv6").."</li>")
+   print("<li>"..i18n("note_flow_search_allowed_networks_counter").."</li>")
+end
+
 print [[
   </div>
 </div>
 
+]]
+
+print[[
 <script type="text/javascript">
 
 var xhr;
@@ -1702,7 +1629,7 @@ print[[
         tr += "<tr><th>" + ipvers + "</th>"
 ]]
 
-if useAggregatedFlows() == false then -- only show flow counters when querying from raw flows
+if not useAggregatedFlows() then -- only show flow counters when querying from raw flows
 print[[
         tr += "<td align='right'>" + item.tot_flows + " Flows</td>"
 ]]
@@ -1736,24 +1663,20 @@ print[[
 
 </script>
 ]]
-historicalFlowsTabTables(ifId, host, epoch_begin, epoch_end, l7proto, l4proto, port, info)
+historicalFlowsTabTables(ifId, host, epoch_begin, epoch_end, l7proto, l4proto, port, info, vlan, profile)
 
 end
 
 -- ##########################################
 
-function historicalFlowsTabTables(ifId, host, epoch_begin, epoch_end, l7proto, l4proto, port, info)
-   local url_update = ntop.getHttpPrefix().."/lua/get_db_flows.lua?ifid="..ifId.. "&peer1="..(host or '') .. "&epoch_begin="..(epoch_begin or '').."&epoch_end="..(epoch_end or '').."&l4proto="..(l4proto or '').."&port="..(port or '').."&info="..(info or '')
+function historicalFlowsTabTables(ifId, host, epoch_begin, epoch_end, l7proto, l4proto, port, info, vlan, profile)
+   local url_update = ntop.getHttpPrefix().."/lua/get_db_flows.lua?ifid="..ifId.. "&peer1="..(host or '') .. "&epoch_begin="..(epoch_begin or '').."&epoch_end="..(epoch_end or '').."&l4proto="..(l4proto or '').."&port="..(port or '').."&info="..(info or '').."&vlan="..(vlan or '').."&profile="..(profile or '')
 
    if(l7proto ~= "") then
       if(not(isnumber(l7proto))) then
 	 local id
 
 	 -- io.write(l7proto.."\n")
-	 l7proto = string.gsub(l7proto, "%.rrd", "")
-
-	 if(string.ends(l7proto, ".rrd")) then l7proto = string.sub(l7proto, 1, -5) end
-
 	 id = interface.getnDPIProtoId(l7proto)
 
 	 if(id ~= -1) then
@@ -1800,7 +1723,7 @@ print [[
 print [[
   var url_update4 = "]] print(url_update) print [[&version=4]]
 
-if useAggregatedFlows() == false then
+if not useAggregatedFlows() and not allowedNetworksRestrictions() then
    print[[&limit=" + $("#tab-ipv4").attr("num_flows")]]
 else
    -- limit computed dynamically
@@ -1951,7 +1874,7 @@ print [[
 
 	    var url_update6 = "]] print(url_update) print [[&version=6]]
 
-if useAggregatedFlows() == false then
+if not useAggregatedFlows() and not allowedNetworksRestrictions() then
    print[[&limit=" + $("#tab-ipv6").attr("num_flows")]]
 else
    -- limit computed dynamically
